@@ -41,14 +41,10 @@
 using namespace com::sun::star;
 using ::std::vector;
 using ::std::list;
-using ::std::hash_set;
 using ::std::auto_ptr;
 using ::std::unary_function;
 using ::std::for_each;
 
-//2do: DocOption TimeOut?
-//#define SC_CHARTTIMEOUT 1000		// eine Sekunde keine Aenderung/KeyEvent
-
 // Update chart listeners quickly, to get a similar behavior to loaded charts
 // which register UNO listeners.
 #define SC_CHARTTIMEOUT 10
@@ -117,7 +113,7 @@ void ScChartListener::ExternalRefListener::removeFileId(sal_uInt16 nFileId)
     maFileIds.erase(nFileId);
 }
 
-hash_set<sal_uInt16>& ScChartListener::ExternalRefListener::getAllFileIds()
+boost::unordered_set<sal_uInt16>& ScChartListener::ExternalRefListener::getAllFileIds()
 {
     return maFileIds;
 }
@@ -129,12 +125,12 @@ ScChartListener::ScChartListener( const String& rName, ScDocument* pDocP,
     StrData( rName ),
     SvtListener(),
     mpExtRefListener(NULL), 
-    mpTokens(new vector<ScSharedTokenRef>), 
+    mpTokens(new vector<ScTokenRef>),
     pUnoData( NULL ),
     pDoc( pDocP ),
-    bUsed( FALSE ),
-    bDirty( FALSE ),
-    bSeriesRangesScheduled( FALSE )
+    bUsed( false ),
+    bDirty( false ),
+    bSeriesRangesScheduled( false )
 {
     SetRangeList( rRange );
 }
@@ -144,26 +140,26 @@ ScChartListener::ScChartListener( const String& rName, ScDocument* pDocP,
     StrData( rName ),
     SvtListener(),
     mpExtRefListener(NULL), 
-    mpTokens(new vector<ScSharedTokenRef>), 
+    mpTokens(new vector<ScTokenRef>),
     pUnoData( NULL ),
     pDoc( pDocP ),
-    bUsed( FALSE ),
-    bDirty( FALSE ),
-    bSeriesRangesScheduled( FALSE )
+    bUsed( false ),
+    bDirty( false ),
+    bSeriesRangesScheduled( false )
 {
     ScRefTokenHelper::getTokensFromRangeList(*mpTokens, *rRangeList);
 }
 
-ScChartListener::ScChartListener( const String& rName, ScDocument* pDocP, vector<ScSharedTokenRef>* pTokens ) :
+ScChartListener::ScChartListener( const String& rName, ScDocument* pDocP, vector<ScTokenRef>* pTokens ) :
     StrData( rName ),
     SvtListener(),
     mpExtRefListener(NULL), 
     mpTokens(pTokens),
     pUnoData( NULL ),
     pDoc( pDocP ),
-    bUsed( FALSE ),
-    bDirty( FALSE ),
-    bSeriesRangesScheduled( FALSE )
+    bUsed( false ),
+    bDirty( false ),
+    bSeriesRangesScheduled( false )
 {
 }
 
@@ -171,10 +167,10 @@ ScChartListener::ScChartListener( const ScChartListener& r ) :
     StrData( r ),
     SvtListener(),
     mpExtRefListener(NULL), 
-    mpTokens(new vector<ScSharedTokenRef>(*r.mpTokens)),
+    mpTokens(new vector<ScTokenRef>(*r.mpTokens)),
     pUnoData( NULL ),
     pDoc( r.pDoc ),
-    bUsed( FALSE ),
+    bUsed( false ),
     bDirty( r.bDirty ),
     bSeriesRangesScheduled( r.bSeriesRangesScheduled )
 {
@@ -187,9 +183,9 @@ ScChartListener::ScChartListener( const ScChartListener& r ) :
         // was listening to.
 
         ScExternalRefManager* pRefMgr = pDoc->GetExternalRefManager();
-        const hash_set<sal_uInt16>& rFileIds = r.mpExtRefListener->getAllFileIds();
+        const boost::unordered_set<sal_uInt16>& rFileIds = r.mpExtRefListener->getAllFileIds();
         mpExtRefListener.reset(new ExternalRefListener(*this, pDoc));
-        hash_set<sal_uInt16>::const_iterator itr = rFileIds.begin(), itrEnd = rFileIds.end();
+        boost::unordered_set<sal_uInt16>::const_iterator itr = rFileIds.begin(), itrEnd = rFileIds.end();
         for (; itr != itrEnd; ++itr)
         {
             pRefMgr->addLinkListener(*itr, mpExtRefListener.get());
@@ -208,8 +204,8 @@ ScChartListener::~ScChartListener()
     {
         // Stop listening to all external files.
         ScExternalRefManager* pRefMgr = pDoc->GetExternalRefManager();
-        const hash_set<sal_uInt16>& rFileIds = mpExtRefListener->getAllFileIds();
-        hash_set<sal_uInt16>::const_iterator itr = rFileIds.begin(), itrEnd = rFileIds.end();
+        const boost::unordered_set<sal_uInt16>& rFileIds = mpExtRefListener->getAllFileIds();
+        boost::unordered_set<sal_uInt16>::const_iterator itr = rFileIds.begin(), itrEnd = rFileIds.end();
         for (; itr != itrEnd; ++itr)
             pRefMgr->removeLinkListener(*itr, mpExtRefListener.get());
     }
@@ -224,7 +220,6 @@ void ScChartListener::SetUno(
         const uno::Reference< chart::XChartDataChangeEventListener >& rListener,
         const uno::Reference< chart::XChartData >& rSource )
 {
-//	DBG_ASSERT( rListener.is() && rSource.is(), "Nullpointer bei SetUno" );
     delete pUnoData;
     pUnoData = new ScChartUnoData( rListener, rSource );
 }
@@ -253,7 +248,7 @@ void ScChartListener::Notify( SvtBroadcaster&, const SfxHint& rHint )
 void ScChartListener::Update()
 {
     if ( pDoc->IsInInterpreter() )
-    {	// #73482# If interpreting do nothing and restart timer so we don't
+    {	// If interpreting do nothing and restart timer so we don't
         // interfere with interpreter and don't produce an Err522 or similar.
         // This may happen if we are rescheduled via Basic function.
         pDoc->GetChartListenerCollection()->StartTimer();
@@ -261,7 +256,7 @@ void ScChartListener::Update()
     }
     if ( pUnoData )
     {
-        bDirty = FALSE;
+        bDirty = false;
         //!	irgendwann mal erkennen, was sich innerhalb des Charts geaendert hat
         chart::ChartDataChangeEvent aEvent( pUnoData->GetSource(),
                                         chart::ChartDataChangeType_ALL,
@@ -270,7 +265,7 @@ void ScChartListener::Update()
     }
     else if ( pDoc->GetAutoCalc() )
     {
-        bDirty = FALSE;
+        bDirty = false;
         pDoc->UpdateChart( GetString());
     }
 }
@@ -284,27 +279,27 @@ ScRangeListRef ScChartListener::GetRangeList() const
 
 void ScChartListener::SetRangeList( const ScRangeListRef& rNew )
 {
-    vector<ScSharedTokenRef> aTokens;
+    vector<ScTokenRef> aTokens;
     ScRefTokenHelper::getTokensFromRangeList(aTokens, *rNew);
     mpTokens->swap(aTokens);
 }
 
 void ScChartListener::SetRangeList( const ScRange& rRange )
 {
-    ScSharedTokenRef pToken;
+    ScTokenRef pToken;
     ScRefTokenHelper::getTokenFromRange(pToken, rRange);
     mpTokens->push_back(pToken);
 }
 
 namespace {
 
-class StartEndListening : public unary_function<ScSharedTokenRef, void>
+class StartEndListening : public unary_function<ScTokenRef, void>
 {
 public:
     StartEndListening(ScDocument* pDoc, ScChartListener& rParent, bool bStart) :
         mpDoc(pDoc), mrParent(rParent), mbStart(bStart) {}
 
-    void operator() (const ScSharedTokenRef& pToken)
+    void operator() (const ScTokenRef& pToken)
     {
         if (!ScRefTokenHelper::isRef(pToken))
             return;
@@ -336,7 +331,6 @@ public:
                 endListening(aRange);
         }
     }
-
 private:
     void startListening(const ScRange& rRange)
     {
@@ -353,7 +347,6 @@ private:
         else
             mpDoc->EndListeningArea(rRange, &mrParent);
     }
-
 private:
     ScDocument* mpDoc;
     ScChartListener& mrParent;
@@ -382,13 +375,13 @@ void ScChartListener::EndListeningTo()
 
 
 void ScChartListener::ChangeListening( const ScRangeListRef& rRangeListRef,
-            BOOL bDirtyP  )
+            sal_Bool bDirtyP  )
 {
     EndListeningTo();
     SetRangeList( rRangeListRef );
     StartListeningTo();
     if ( bDirtyP )
-        SetDirty( TRUE );
+        SetDirty( sal_True );
 }
 
 
@@ -396,7 +389,7 @@ void ScChartListener::UpdateScheduledSeriesRanges()
 {
     if ( bSeriesRangesScheduled )
     {
-        bSeriesRangesScheduled = FALSE;
+        bSeriesRangesScheduled = false;
         UpdateSeriesRanges();
     }
 }
@@ -404,7 +397,7 @@ void ScChartListener::UpdateScheduledSeriesRanges()
 
 void ScChartListener::UpdateChartIntersecting( const ScRange& rRange )
 {
-    ScSharedTokenRef pToken;
+    ScTokenRef pToken;
     ScRefTokenHelper::getTokenFromRange(pToken, rRange);
 
     if (ScRefTokenHelper::intersects(*mpTokens, pToken))
@@ -436,7 +429,7 @@ void ScChartListener::SetUpdateQueue()
     pDoc->GetChartListenerCollection()->StartTimer();
 }
 
-BOOL ScChartListener::operator==( const ScChartListener& r )
+sal_Bool ScChartListener::operator==( const ScChartListener& r )
 {
     bool b1 = (mpTokens.get() && !mpTokens->empty());
     bool b2 = (r.mpTokens.get() && !r.mpTokens->empty());
@@ -472,7 +465,7 @@ ScChartListenerCollection::RangeListenerItem::RangeListenerItem(const ScRange& r
 }
 
 ScChartListenerCollection::ScChartListenerCollection( ScDocument* pDocP ) :
-    ScStrCollection( 4, 4, FALSE ),
+    ScStrCollection( 4, 4, false ),
     pDoc( pDocP )
 {
     aTimer.SetTimeoutHdl( LINK( this, ScChartListenerCollection, TimerHdl ) );
@@ -488,7 +481,7 @@ ScChartListenerCollection::ScChartListenerCollection(
 
 ScChartListenerCollection::~ScChartListenerCollection()
 {
-    //	#96783# remove ChartListener objects before aTimer dtor is called, because
+    //	remove ChartListener objects before aTimer dtor is called, because
     //	ScChartListener::EndListeningTo may cause ScChartListenerCollection::StartTimer
     //	to be called if an empty ScNoteCell is deleted
 
@@ -503,18 +496,18 @@ ScDataObject*	ScChartListenerCollection::Clone() const
 
 void ScChartListenerCollection::StartAllListeners()
 {
-    for ( USHORT nIndex = 0; nIndex < nCount; nIndex++ )
+    for ( sal_uInt16 nIndex = 0; nIndex < nCount; nIndex++ )
     {
         ((ScChartListener*) pItems[ nIndex ])->StartListeningTo();
     }
 }
 
 void ScChartListenerCollection::ChangeListening( const String& rName,
-        const ScRangeListRef& rRangeListRef, BOOL bDirty )
+        const ScRangeListRef& rRangeListRef, sal_Bool bDirty )
 {
     ScChartListener aCLSearcher( rName, pDoc, rRangeListRef );
     ScChartListener* pCL;
-    USHORT nIndex;
+    sal_uInt16 nIndex;
     if ( Search( &aCLSearcher, nIndex ) )
     {
         pCL = (ScChartListener*) pItems[ nIndex ];
@@ -528,13 +521,13 @@ void ScChartListenerCollection::ChangeListening( const String& rName,
     }
     pCL->StartListeningTo();
     if ( bDirty )
-        pCL->SetDirty( TRUE );
+        pCL->SetDirty( sal_True );
 }
 
 void ScChartListenerCollection::FreeUnused()
 {
     // rueckwaerts wg. Pointer-Aufrueckerei im Array
-    for ( USHORT nIndex = nCount; nIndex-- >0; )
+    for ( sal_uInt16 nIndex = nCount; nIndex-- >0; )
     {
         ScChartListener* pCL = (ScChartListener*) pItems[ nIndex ];
         //	Uno-Charts nicht rauskicken
@@ -542,7 +535,7 @@ void ScChartListenerCollection::FreeUnused()
         if ( !pCL->IsUno() )
         {
             if ( pCL->IsUsed() )
-                pCL->SetUsed( FALSE );
+                pCL->SetUsed( false );
             else
                 Free( pCL );
         }
@@ -553,7 +546,7 @@ void ScChartListenerCollection::FreeUno( const uno::Reference< chart::XChartData
                                          const uno::Reference< chart::XChartData >& rSource )
 {
     // rueckwaerts wg. Pointer-Aufrueckerei im Array
-    for ( USHORT nIndex = nCount; nIndex-- >0; )
+    for ( sal_uInt16 nIndex = nCount; nIndex-- >0; )
     {
         ScChartListener* pCL = (ScChartListener*) pItems[ nIndex ];
         if ( pCL->IsUno() &&
@@ -585,7 +578,7 @@ IMPL_LINK( ScChartListenerCollection, TimerHdl, Timer*, EMPTYARG )
 
 void ScChartListenerCollection::UpdateDirtyCharts()
 {
-    for ( USHORT nIndex = 0; nIndex < nCount; nIndex++ )
+    for ( sal_uInt16 nIndex = 0; nIndex < nCount; nIndex++ )
     {
         ScChartListener* pCL = (ScChartListener*) pItems[ nIndex ];
         if ( pCL->IsDirty() )
@@ -598,24 +591,24 @@ void ScChartListenerCollection::UpdateDirtyCharts()
 
 void ScChartListenerCollection::SetDirty()
 {
-    for ( USHORT nIndex = 0; nIndex < nCount; nIndex++ )
+    for ( sal_uInt16 nIndex = 0; nIndex < nCount; nIndex++ )
     {
         ScChartListener* pCL = (ScChartListener*) pItems[ nIndex ];
-        pCL->SetDirty( TRUE );
+        pCL->SetDirty( sal_True );
     }
     StartTimer();
 }
 
 
 void ScChartListenerCollection::SetDiffDirty(
-            const ScChartListenerCollection& rCmp, BOOL bSetChartRangeLists )
+            const ScChartListenerCollection& rCmp, sal_Bool bSetChartRangeLists )
 {
-    BOOL bDirty = FALSE;
-    for ( USHORT nIndex = 0; nIndex < nCount; nIndex++ )
+    sal_Bool bDirty = false;
+    for ( sal_uInt16 nIndex = 0; nIndex < nCount; nIndex++ )
     {
         ScChartListener* pCL = (ScChartListener*) pItems[ nIndex ];
-        USHORT nFound;
-        BOOL bFound = rCmp.Search( pCL, nFound );
+        sal_uInt16 nFound;
+        sal_Bool bFound = rCmp.Search( pCL, nFound );
         if ( !bFound ||	(*pCL != *((const ScChartListener*) rCmp.pItems[ nFound ])) )
         {
             if ( bSetChartRangeLists )
@@ -625,16 +618,16 @@ void ScChartListenerCollection::SetDiffDirty(
                     const ScRangeListRef& rList1 = pCL->GetRangeList();
                     const ScRangeListRef& rList2 =
                         ((const ScChartListener*) rCmp.pItems[ nFound ])->GetRangeList();
-                    BOOL b1 = rList1.Is();
-                    BOOL b2 = rList2.Is();
+                    sal_Bool b1 = rList1.Is();
+                    sal_Bool b2 = rList2.Is();
                     if ( b1 != b2 || (b1 && b2 && (*rList1 != *rList2)) )
                         pDoc->SetChartRangeList( pCL->GetString(), rList1 );
                 }
                 else
                     pDoc->SetChartRangeList( pCL->GetString(), pCL->GetRangeList() );
             }
-            bDirty = TRUE;
-            pCL->SetDirty( TRUE );
+            bDirty = sal_True;
+            pCL->SetDirty( sal_True );
         }
     }
     if ( bDirty )
@@ -644,15 +637,15 @@ void ScChartListenerCollection::SetDiffDirty(
 
 void ScChartListenerCollection::SetRangeDirty( const ScRange& rRange )
 {
-    BOOL bDirty = FALSE;
-    for ( USHORT nIndex = 0; nIndex < nCount; nIndex++ )
+    sal_Bool bDirty = false;
+    for ( sal_uInt16 nIndex = 0; nIndex < nCount; nIndex++ )
     {
         ScChartListener* pCL = (ScChartListener*) pItems[ nIndex ];
         const ScRangeListRef& rList = pCL->GetRangeList();
         if ( rList.Is() && rList->Intersects( rRange ) )
         {
-            bDirty = TRUE;
-            pCL->SetDirty( TRUE );
+            bDirty = sal_True;
+            pCL->SetDirty( sal_True );
         }
     }
     if ( bDirty )
@@ -670,7 +663,7 @@ void ScChartListenerCollection::SetRangeDirty( const ScRange& rRange )
 
 void ScChartListenerCollection::UpdateScheduledSeriesRanges()
 {
-    for ( USHORT nIndex = 0; nIndex < nCount; nIndex++ )
+    for ( sal_uInt16 nIndex = 0; nIndex < nCount; nIndex++ )
     {
         ScChartListener* pCL = (ScChartListener*) pItems[ nIndex ];
         pCL->UpdateScheduledSeriesRanges();
@@ -681,7 +674,7 @@ void ScChartListenerCollection::UpdateScheduledSeriesRanges()
 void ScChartListenerCollection::UpdateChartsContainingTab( SCTAB nTab )
 {
     ScRange aRange( 0, 0, nTab, MAXCOL, MAXROW, nTab );
-    for ( USHORT nIndex = 0; nIndex < nCount; nIndex++ )
+    for ( sal_uInt16 nIndex = 0; nIndex < nCount; nIndex++ )
     {
         ScChartListener* pCL = (ScChartListener*) pItems[ nIndex ];
         pCL->UpdateChartIntersecting( aRange );
@@ -689,19 +682,19 @@ void ScChartListenerCollection::UpdateChartsContainingTab( SCTAB nTab )
 }
 
 
-BOOL ScChartListenerCollection::operator==( const ScChartListenerCollection& r )
+sal_Bool ScChartListenerCollection::operator==( const ScChartListenerCollection& r )
 {
     // hier nicht ScStrCollection::operator==() verwenden, der umstaendlich via
     // IsEqual und Compare laeuft, stattdessen ScChartListener::operator==()
     if ( pDoc != r.pDoc || nCount != r.nCount )
-        return FALSE;
-    for ( USHORT nIndex = 0; nIndex < nCount; nIndex++ )
+        return false;
+    for ( sal_uInt16 nIndex = 0; nIndex < nCount; nIndex++ )
     {
         if ( *((ScChartListener*) pItems[ nIndex ]) !=
                 *((ScChartListener*) r.pItems[ nIndex ]) )
-            return FALSE;
+            return false;
     }
-    return TRUE;
+    return sal_True;
 }
 
 void ScChartListenerCollection::StartListeningHiddenRange( const ScRange& rRange, ScChartHiddenRangeListener* pListener )
